==> qmmp-plugin-pack-0.8.6.tar.bz2: qmmp-plugin-pack-0.8.6/src/Input/ffap/translations/ffap_plugin_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>DecoderFFapFactory</name>
    <message>
        <location filename="../decoderffapfactory.cpp" line="48"/>
        <source>FFap Plugin</source>
        <translation>FFap-Modul</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="50"/>
        <source>Monkey&apos;s Audio Files</source>
        <translation>„Monkey’s Audio“-Dateien</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="153"/>
        <source>About FFap Audio Plugin</source>
        <translation>Über FFap-Audio-Modul</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="154"/>
        <source>Qmmp FFap Audio Plugin</source>
        <translation>Qmmp FFap-Audio-Modul</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="155"/>
        <source>This plugin provides Monkey&apos;s Audio (APE) support</source>
        <translation>Dieses Modul fügt Unterstützung für „Monkey’s Audio“ (APE) hinzu</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="156"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="157"/>
        <source>Based on code from deadbeef, FFmpeg and rockbox</source>
        <translation>Basiert auf Code von deadbeef, FFmpeg und Rockbox</translation>
    </message>
</context>
<context>
    <name>FFapMetaDataModel</name>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="60"/>
        <source>Length</source>
        <translation>Länge</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="61"/>
        <source>Sample rate</source>
        <translation>Abtastrate</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="61"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="62"/>
        <source>Channels</source>
        <translation>Kanäle</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="63"/>
        <source>Bitrate</source>
        <translation>Bitrate</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="63"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="64"/>
        <source>File size</source>
        <translation>Dateigröße</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="64"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
</context>
</TS>

==> qmmp-plugin-pack-0.9.3.tar.bz2: qmmp-plugin-pack-0.9.3/src/Input/ffap/translations/ffap_plugin_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de">
<context>
    <name>DecoderFFapFactory</name>
    <message>
        <location filename="../decoderffapfactory.cpp" line="51"/>
        <source>FFap Plugin</source>
        <translation>FFap-Modul</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="53"/>
        <source>Monkey&apos;s Audio Files</source>
        <translation>Monkey’s-Audio-Dateien</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="161"/>
        <source>About FFap Audio Plugin</source>
        <translation>Über FFap-Audio-Modul</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="162"/>
        <source>Qmmp FFap Audio Plugin</source>
        <translation>Qmmp FFap-Audio-Modul</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="163"/>
        <source>This plugin provides Monkey&apos;s Audio (APE) support</source>
        <translation>Dieses Modul fügt Unterstützung für Monkey’s Audio (APE) hinzu</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="164"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Geschrieben von: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="165"/>
        <source>Based on code from deadbeef, FFmpeg and rockbox</source>
        <translation>Basiert auf Code von deadbeef, FFmpeg und Rockbox</translation>
    </message>
</context>
<context>
    <name>FFapMetaDataModel</name>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="60"/>
        <source>Length</source>
        <translation>Länge</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="61"/>
        <source>Sample rate</source>
        <translation>Abtastrate</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="61"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="62"/>
        <source>Channels</source>
        <translation>Kanäle</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="63"/>
        <source>Bitrate</source>
        <translation>Bitrate</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="63"/>
        <source>kbps</source>
        <translation>kbit/s</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="64"/>
        <source>File size</source>
        <translation>Dateigröße</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="64"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
</context>
</TS>
